#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pcre-heavy
version:              1.0.0.2
visibility:           public
id:                   pcre-heavy-1.0.0.2-BMe3RcTuy4fEHFjL5gnWgf
key:                  pcre-heavy-1.0.0.2-BMe3RcTuy4fEHFjL5gnWgf
license:              LicenseRef-PublicDomain
copyright:            2015 Greg V <greg@unrelenting.technology>
maintainer:           greg@unrelenting.technology
author:               Greg V
homepage:             https://github.com/myfreeweb/pcre-heavy
synopsis:             A regexp library on top of pcre-light you can actually use.
description:
    A regular expressions library that does not suck.
    Based on <https://hackage.haskell.org/package/pcre-light pcre-light>.
    Takes and returns <https://hackage.haskell.org/package/stringable Stringables> everywhere.
    Includes a QuasiQuoter for regexps that does compile time checking.
    SEARCHES FOR MULTIPLE MATCHES! DOES REPLACEMENT!

category:             Web
abi:                  ed972e5b2fb91ab4a990ae8bf164090f
exposed:              True
exposed-modules:      Text.Regex.PCRE.Heavy
import-dirs:          /usr/lib/ghc-8.10.5/site-local/pcre-heavy-1.0.0.2
library-dirs:         /usr/lib/ghc-8.10.5/site-local/pcre-heavy-1.0.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/pcre-heavy-1.0.0.2
hs-libraries:         HSpcre-heavy-1.0.0.2-BMe3RcTuy4fEHFjL5gnWgf
depends:
    base-4.14.2.0 base-compat-0.11.2-Eyusxyk2CrTGloLdon9bIK
    bytestring-0.10.12.0 pcre-light-0.4.1.0-H2hxeQpSItnJ59X9TljXv
    string-conversions-0.4.0.1-2hCpm9KzYph7xvod4dEvyg
    template-haskell-2.16.0.0

haddock-interfaces:   /usr/share/doc/haskell-pcre-heavy/html/pcre-heavy.haddock
haddock-html:         /usr/share/doc/haskell-pcre-heavy/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

